@@ -4,7 +4,7 @@
 -- SPDX-FileCopyrightText: Copyright (c) 2025 Objectionary.com
 -- SPDX-License-Identifier: MIT
 
-module Dataize (morph, dataize, dataize', DataizeContext (..), defaultDataizeContext) where
+module Dataize (morph, dataize, dataize', DataizeContext (..)) where
 
 import Ast
 import Builder (contextualize)
@@ -13,20 +13,19 @@ import Control.Exception (throwIO)
 import Data.List (partition)
 import Misc
 import Rewriter (RewriteContext (RewriteContext), rewrite')
+import Term (BuildTermFunc)
 import Text.Printf (printf)
 import XMIR (XmirContext (XmirContext))
 import Yaml (normalizationRules)
 
 data DataizeContext = DataizeContext
-  { program :: Program,
-    maxDepth :: Integer
+  { _program :: Program,
+    _maxDepth :: Integer,
+    _buildTerm :: BuildTermFunc
   }
 
-defaultDataizeContext :: Program -> DataizeContext
-defaultDataizeContext prog = DataizeContext prog 25
-
 switchContext :: DataizeContext -> RewriteContext
-switchContext DataizeContext {..} = RewriteContext program maxDepth
+switchContext DataizeContext {..} = RewriteContext _program _maxDepth _buildTerm
 
 maybeBinding :: (Binding -> Bool) -> [Binding] -> (Maybe Binding, [Binding])
 maybeBinding _ [] = (Nothing, [])
@@ -81,10 +80,10 @@ withTail (ExDispatch (ExFormation bds) attr) ctx = do
     Just obj -> pure (Just (ExDispatch obj attr))
     _ -> pure Nothing
 withTail (ExFormation bds) ctx = formation bds ctx
-withTail (ExDispatch (ExDispatch ExGlobal (AtLabel label)) attr) (DataizeContext {program = Program expr}) = case phiDispatch label expr of
+withTail (ExDispatch (ExDispatch ExGlobal (AtLabel label)) attr) (DataizeContext {_program = Program expr}) = case phiDispatch label expr of
   Just obj -> pure (Just (ExDispatch obj attr))
   _ -> pure Nothing
-withTail (ExDispatch ExGlobal (AtLabel label)) (DataizeContext {program = Program expr}) = pure (phiDispatch label expr)
+withTail (ExDispatch ExGlobal (AtLabel label)) (DataizeContext {_program = Program expr}) = pure (phiDispatch label expr)
 withTail (ExDispatch expr attr) ctx = do
   exp' <- withTail expr ctx
   case exp' of
@@ -128,10 +127,10 @@ morph expr ctx = do
 -- BOX:   D([B1, 𝜑 -> e, B2]) -> D(С(e))        if [B1,B2] has no delta/lambda, where С(e) - contextualization
 -- NORM:  D(e1) -> D(e2)                        if e2 := M(e1) and e1 is not primitive
 --        nothing                               otherwise
-dataize :: Program -> DataizeContext -> IO (Maybe String)
+dataize :: Program -> DataizeContext -> IO (Maybe Bytes)
 dataize (Program expr) = dataize' expr
 
-dataize' :: Expression -> DataizeContext -> IO (Maybe String)
+dataize' :: Expression -> DataizeContext -> IO (Maybe Bytes)
 dataize' ExTermination _ = pure Nothing
 dataize' (ExFormation bds) ctx = case maybeDelta bds of
   (Just (BiDelta bytes), _) -> pure (Just bytes)
@@ -139,7 +138,7 @@ dataize' (ExFormation bds) ctx = case maybeDelta bds of
     (Just (BiTau AtPhi expr), bds') -> case maybeLambda bds' of
       (Just (BiLambda _), _) -> throwIO (userError "The 𝜑 and λ can't be present in formation at the same time")
       (_, _) ->
-        let expr' = contextualize expr (ExFormation bds) (program ctx)
+        let expr' = contextualize expr (ExFormation bds) (_program ctx)
          in dataize' expr' ctx
     (Nothing, _) -> case maybeLambda bds of
       (Just (BiLambda _), _) -> do
@@ -163,30 +162,30 @@ atom "L_org_eolang_number_plus" self ctx = do
   right <- dataize' (ExDispatch self AtRho) ctx
   case (left, right) of
     (Just left', Just right') -> do
-      let first = either toDouble id (hexToNum left')
-          second = either toDouble id (hexToNum right')
+      let first = either toDouble id (btsToNum left')
+          second = either toDouble id (btsToNum right')
           sum = first + second
-      pure (Just (DataObject "number" (numToHex sum)))
+      pure (Just (DataObject "number" (numToBts sum)))
     _ -> pure Nothing
 atom "L_org_eolang_number_times" self ctx = do
   left <- dataize' (ExDispatch self (AtLabel "x")) ctx
   right <- dataize' (ExDispatch self AtRho) ctx
   case (left, right) of
     (Just left', Just right') -> do
-      let first = either toDouble id (hexToNum left')
-          second = either toDouble id (hexToNum right')
+      let first = either toDouble id (btsToNum left')
+          second = either toDouble id (btsToNum right')
           sum = first * second
-      pure (Just (DataObject "number" (numToHex sum)))
+      pure (Just (DataObject "number" (numToBts sum)))
     _ -> pure Nothing
 atom "L_org_eolang_number_eq" self ctx = do
   x <- dataize' (ExDispatch self (AtLabel "x")) ctx
   rho <- dataize' (ExDispatch self AtRho) ctx
   case (x, rho) of
     (Just x', Just rho') -> do
-      let self' = either toDouble id (hexToNum rho')
-          first = either toDouble id (hexToNum x')
+      let self' = either toDouble id (btsToNum rho')
+          first = either toDouble id (btsToNum x')
       if self' == first
-        then pure (Just (DataObject "number" (numToHex first)))
+        then pure (Just (DataObject "number" (numToBts first)))
         else pure (Just (ExDispatch self (AtLabel "y")))
     _ -> pure Nothing
 atom func _ _ = throwIO (userError (printf "Atom '%s' does not exist" func))
\ No newline at end of file
