@@ -7,7 +7,7 @@ module Logger
     logWarning,
     logError,
     setLogLevel,
-    LogLevel(DEBUG, INFO, WARNING, ERROR, NONE),
+    LogLevel (DEBUG, INFO, WARNING, ERROR, NONE),
   )
 where
 
@@ -15,8 +15,6 @@ import Control.Monad (when)
 import Data.IORef (IORef, newIORef, readIORef, writeIORef)
 import GHC.IO (unsafePerformIO)
 import System.IO
-import Text.Printf (printf)
-import Options.Applicative (ReadM)
 
 data LogLevel = DEBUG | INFO | WARNING | ERROR | NONE
   deriving (Show, Ord, Eq, Bounded, Enum, Read)
@@ -25,7 +23,7 @@ newtype Logger = Logger {level :: LogLevel}
 
 logger :: IORef Logger
 {-# NOINLINE logger #-}
-logger = unsafePerformIO (newIORef (Logger INFO))
+logger = unsafePerformIO (newIORef (Logger DEBUG))
 
 setLogLevel :: LogLevel -> IO ()
 setLogLevel lvl = writeIORef logger (Logger lvl)
